<?php

namespace Litecms\CompanySetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CompanySetting\Models\CompanySetting;

class CompanySettingPolicy
{

    /**
     * Determine if the given user can view the company_setting.
     *
     * @param UserPolicy $user
     * @param CompanySetting $company_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, CompanySetting $company_setting)
    {
        if ($user->canDo('company_setting.company_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $company_setting->user_id == user_id() && $company_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a company_setting.
     *
     * @param UserPolicy $user
     * @param CompanySetting $company_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_setting.company_setting.create');
    }

    /**
     * Determine if the given user can update the given company_setting.
     *
     * @param UserPolicy $user
     * @param CompanySetting $company_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, CompanySetting $company_setting)
    {
        if ($user->canDo('company_setting.company_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $company_setting->user_id == user_id() && $company_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given company_setting.
     *
     * @param UserPolicy $user
     * @param CompanySetting $company_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CompanySetting $company_setting)
    {
        return $company_setting->user_id == user_id() && $company_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given company_setting.
     *
     * @param UserPolicy $user
     * @param CompanySetting $company_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CompanySetting $company_setting)
    {
        if ($user->canDo('company_setting.company_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given company_setting.
     *
     * @param UserPolicy $user
     * @param CompanySetting $company_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CompanySetting $company_setting)
    {
        if ($user->canDo('company_setting.company_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
