<?php

namespace Litecms\CompanySetting\Providers;

use Illuminate\Support\ServiceProvider;

class CompanySettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'company_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'company_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.company_setting', function ($app) {
            return $this->app->make('Litecms\CompanySetting\CompanySetting');
        });

                // Bind CompanySetting to repository
        $this->app->bind(
            'Litecms\CompanySetting\Interfaces\CompanySettingRepositoryInterface',
            \Litecms\CompanySetting\Repositories\Eloquent\CompanySettingRepository::class
        );

        $this->app->register(\Litecms\CompanySetting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\CompanySetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.company_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/company_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/company_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/company_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
